;;;;;;;;;;;;;;;;;;;;; Introduction  and Defuns          ;;;;;;;;;;;;;;;;;;;;;;;

;; multilingual and multiplatform dotemacs
;; Alexander Mikhailian <mikhailian@altern.org>

(defmacro GNUEmacs (&rest x)
  (list 'if (string-match "GNU Emacs"    (prin1-to-string (version)))   (cons 'progn x)))
(defmacro GNUEmacs20 (&rest x)
  (list 'if (string-match "GNU Emacs 20" (prin1-to-string (version)))   (cons 'progn x)))
(defmacro GNUEmacs21 (&rest x)
  (list 'if (string-match "GNU Emacs 21" (prin1-to-string (version)))   (cons 'progn x)))
(defmacro XEmacs (&rest x)
  (list 'if (string-match "XEmacs 21"    (prin1-to-string (version)))   (cons 'progn x)))
(defmacro GNULinux (&rest x)
  (list 'if (string-match "linux"        (prin1-to-string system-type)) (cons 'progn x)))
(defmacro Windows (&rest x)
  (list 'if (string-match "windows"      (prin1-to-string system-type)) (cons 'progn x)))

;;;;;;;;;;;;;;;;;;;;; Load Paths                        ;;;;;;;;;;;;;;;;;;;;;;;

(GNUEmacs
 (setq 
  load-path (cons "/home/login/emacs/user-lisp" load-path)
       )
 ) ;; GNUEmacs

(Windows
 (setq 
  load-path (cons "E:/cygwin/home/login/emacs/user-lisp" load-path))
 ) ;; Windows

;;;;;;;;;;;;;;;;;;;;; Charsets Customization            ;;;;;;;;;;;;;;;;;;;;;;;

;; Defining additional coding systems

;; Russian DOS
(defvar cp866-decode-table
  [
        255 240 nil nil 242 nil nil 244 nil nil nil nil nil nil 246 nil
        128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143
        144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159
        160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175
        224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239
        252 241 nil nil 243 nil nil 245 nil nil nil nil nil nil 247 nil]
  "Table for converting ISO-8859-5 characters into codepage 866 glyphs.")
(setplist 'cp866-decode-table
          '(charset cyrillic-iso8859-5 language "Cyrillic-ISO" offset 160))

;; Greek DOS
(defvar cp737-decode-table
  [
        255 nil nil nil nil nil nil nil nil nil nil nil nil nil nil nil
        248 nil 253 nil nil nil 234 250 235 236 237 nil 238 nil 239 240
        nil 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142
        143 144 nil 145 146 147 148 149 150 151 244 245 225 226 227 229
        nil 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166
        167 168 170 169 171 172 173 174 175 224 228 232 230 231 232 nil]
        "Table for converting ISO-8859-7 characters into codepage 737 glyphs.")
(setplist 'cp737-decode-table
          '(charset greek-iso8859-7 language "Greek" offset 160))

; setting coding systems
(GNUEmacs
 (codepage-setup 437) ;; ascii
 (codepage-setup 737) ;; Greek old
 (codepage-setup 869) ;; Greek old
 (codepage-setup 851) ;; Greek oldest
 (codepage-setup 866) ;; Russian DOS
 (codepage-setup 1251)
 (set-terminal-coding-system 'cp1251)
 (set-keyboard-coding-system nil)
 (setq default-buffer-file-coding-system 'cp1251)
 (set-selection-coding-system 'cp1251)
 (prefer-coding-system 'cp1251)
 (define-coding-system-alias 'windows-1251 'cp1251)
 (define-coding-system-alias 'microsoft-1251 'cp1251)
 (define-coding-system-alias 'microsoft-cp1251 'cp1251)
 (define-coding-system-alias 'windows-cp1251 'cp1251)
 (define-coding-system-alias 'koi8-u 'cyrillic-koi8)
 (define-coding-system-alias 'KOI8-R 'cyrillic-koi8)
 (modify-coding-system-alist 'file "\.*" 'cp1251)
 (modify-coding-system-alist 'file "\\.el$" 'iso-2022-7bit))

;; Do not expand unprintable characters to their octal values
(standard-display-8bit 128 255)

;; PC-like bindings
(GNUEmacs
 (pc-bindings-mode)
 (pc-selection-mode))

(condition-case err
    (require 'belarusian)
  (error
   (message "Cannot load belaruisan input method %s" (cdr err))))

(condition-case err
    (require 'htmlize)
  (error
   (message "Cannot load htmlize %s" (cdr err))))

;; Nice buffer handling when many files are open
(condition-case err
    (require 'msb)
  (error
   (message "Cannot load msb %s" (cdr err))))

;; Nice buffer handling when many files are open
(condition-case err
(require 'dictionary)
  (error
   (message "Cannot load dictionary %s" (cdr err))))

(condition-case err
(require 'blank-mode)
  (error
   (message "Cannot load blank-mode %s" (cdr err))))

(condition-case err
(require 'python-mode)
  (error
   (message "Cannot load python-mode %s" (cdr err))))

(condition-case err
(require 'css-mode)
  (error
   (message "Cannot load css-mode %s" (cdr err))))

(condition-case err
    (require 'ansi-color)
  (error
   (message "Cannot load ansi-color %s" (cdr err))))
(autoload 'ansi-color-for-comint-mode-on "ansi-color" nil t)
(add-hook 'shell-mode-hook 'ansi-color-for-comint-mode-on)

;;Run shashdot headline fetcher
(condition-case err
    (require 'slashdot)
(setq slashdot-proxy "yourproxy"
      slashdot-proxyport 8080)
  (error
   (message "Cannot load slashdot headline fetcher %s" (cdr err))))

(autoload 'xrdb-mode "xrdb-mode" nil t)
(autoload 'fetchmail-mode "fetchmail-mode" nil t)

;; (condition-case err
;;     (and
;;     (require 'ebnf2ps)
;;     (setq
;;      ebnf-syntax 'yacc ;; put as much on one sheet as possible
;;      ps-n-up-printing 2 ;; print on 2 pages
;;      ebnf-horizontal-orientation t))
;;   (error
;;    (message "Cannot load ebnf2ps converter %s" (cdr err))))

;;(condition-case err
;;    (and(require 'table)
;;        (add-hook 'text-mode-hook 'table-recognize))
;;  (error
;;   (message "Cannot load table  %s" (cdr err))))

;;(condition-case err
;;    (and(require 'color-theme)
;;        (color-theme-gnome2))
;;  (error
;;   (message "Cannot load color-teme %s" (cdr err))))

 (require 'backup-dir)
 (setq bkup-backup-directory-info
       '(
         ("/home/login/.*" "~/.backups/" ok-create full-path prepend-name)
         )
       )

;;;;;;;;;;;;;;;;;;;;; Font-Lock Settings                ;;;;;;;;;;;;;;;;;;;;;;;
(cond
 ((fboundp 'global-font-lock-mode)
  (global-font-lock-mode t)
  (setq lazy-lock-stealth-time 2         ; fontify yet unfontified areas after idle time (secs)
        lazy-lock-minimum-size 50000     ; don't fontify if buf is greater than this num. of chars
        lazy-lock-defer-on-scrolling nil ; fontify if scrolling into unfontified area
        lazy-lock-defer-on-the-fly nil   ; perform on-the-fly fontification as you type new chars
        lazy-lock-defer-contextually t   ; perform deferred fontification on modified+subseq. lines
        lazy-lock-stealth-verbose t
        font-lock-support-mode 'lazy-lock-mode ; or fast-lock-mode
        font-lock-maximum-decoration t)))

;;  Highlight selection
(GNUEmacs
 (transient-mark-mode t))

;; Highlight matching parentheses
(GNUEmacs
 (show-paren-mode t))

;;Changing .h to use automatic C++ formatting (instead of standard C)
(setq auto-mode-alist
      (append
       '(
         ("\\.h$"             . c++-mode)
         ("\\.dps$"           . pascal-mode)
         ("\\.l$"             . c-mode)
         ("\\.y$"             . c-mode)
         ("\\.py$"            . python-mode)
         ("\\.css$"           . css-mode)
         ("\\.Xdefaults$"     . xrdb-mode)
         ("\\.Xenvironment$"  . xrdb-mode)
         ("\\.Xresources$"    . xrdb-mode)
         ("*.\\.ad$"          . xrdb-mode)
         ("\\.fetchmailrc$"   . fetchmail-mode)
         ) auto-mode-alist)
      )

;;;;;;;;;;;;;;;;;;;;; Interface and Key Bindings        ;;;;;;;;;;;;;;;;;;;;;;;

;; Display pictures in GNU Emacs 21
(GNUEmacs21
 (auto-image-file-mode 1))

;; automatic resizing of the minibuffer
(resize-minibuffer-mode 1)

;; make searches case-INsensitive
(set-default 'case-fold-search t)

;; This makes `apropos' and `super-apropos'
;; do everything that they can and run slower.
(setq apropos-do-all t)

;; Stop ^M's from displaying in system shell window
(add-hook 'comint-output-filter-functions 'shell-strip-ctrl-m nil t)

;; This tells emacs to show the column number in each modeline.
(column-number-mode 1)

;; Wrap lines while typing in text mode
;; (add-hook 'text-mode-hook 'auto-fill-mode t)

;; Don't wrap long lines when viewing
(GNUEmacs
 (hscroll-global-mode t))

(setq inhibit-startup-message t   ; remove the startup message
      next-line-add-newlines nil  ; don't add new lines when scrolling down
      delete-old-versions t       ; delete excess backup versions
      ;; make-backup-files nil    ; do not make backup files
      scroll-step 1               ; do only one line scrolling
      default-tab-width 2         ; setting the defualt tabulation
      indent-tabs-mode nil        ; do not use tabs for indentation
      display-time-24hr-format t  ; dispaly time in the modeline
      display-time-day-and-date t
      european-calendar-style t   ; customize the calendar
      calendar-week-start-day 1
      calendar-latitude 51.05
      calendar-longitude -2.39
      calendar-location-name "Yourtown"
      ;; debug-on-error t         ; enable to debug
      ;; debug-on-quit t
      )

;; Shut off message buffer.
;; (setq message-log-max nil)
;; (kill-buffer "*Messages*")

;; Make all "yes or no" prompts show "y or n" instead
(fset 'yes-or-no-p 'y-or-n-p)

;; set autocompletion on
(dynamic-completion-mode) ;;!!! slows startup !!!

;; We want compression support, entering tgz files etc.. :)
;;(auto-compression-mode t) ;; !!! slows startup !!!

;; This turns off the GUI menus in X.
;; (menu-bar-mode nil))

;; Shut off annoying beep
;; Works only on Windows?
(Windows
 (set-message-beep 'silent))

;;;;;;;;;;;;;;;;;;;;; Frame Title Bar Formatting        ;;;;;;;;;;;;;;;;;;;;;;;
(setq-default
 frame-title-format
 (list
  '((buffer-file-name
     " %f"
     (dired-directory
      dired-directory
      (revert-buffer-function
       " %b"
       ("%b - Dir:  " default-directory)))))))

(setq-default
 icon-title-format
 (list
  '((buffer-file-name
     " %f"
     (dired-directory
      dired-directory
      (revert-buffer-function
       " %b"
       ("%b - Dir:  " default-directory)))))))

;;;;;;;;;;;;;;;;;;;;; W3 Customization                  ;;;;;;;;;;;;;;;;;;;;;;;
(custom-set-variables
 '(url-be-asynchronous t)
 '(url-external-retrieval-program "wget")
 '(url-mail-command (quote mail)))
(eval-after-load "mule-sysdp"
  '(push '("windows-1251" . cp1251) w3-mime-charset-coding-alist))

;;;;;;;;;;;;;;;;;;;;; Mail Customization                ;;;;;;;;;;;;;;;;;;;;;;;
(setq user-name "loginname")
(setq user-full-name "Full Name")
(setq user-mail-address "loginname@localhost")
(setq mail-default-headers
                        "Content-Type: text/plain; charset=windows-1251\n")
; assign a prefix for each quoted line in email replies and forwards
(setq mail-yank-prefix ">")

; copy all outgoing messages to a file
;;(setq mail-archive-file-name "~/nsmail/Sent")

; specify location of primary mail folder
;;(setq rmail-file-name "~/mail/RMAIL")

; automatically append .signature to end of emails
(setq mail-signature t)


;;;;;;;;;;;;;;;;;;;;; Gnus Customization                ;;;;;;;;;;;;;;;;;;;;;;;
(setq gnus-check-new-newsgroups nil
      gnus-read-active-file nil ;; do not check for new newsgroups, etc
;;      gnus-nov-is-evil nil
      gnus-asynchronous t ;; fetch articles in background
      gnus-select-method '(nntp "ddt.demos.su")
      system-name "localhost")

;; The following lines make the startup much slower
(gnus-mule-add-group "fido7" 'cyrillic-koi8)

;;;;;;;;;;;;;;;;;;;;; Dired Customization               ;;;;;;;;;;;;;;;;;;;;;;;
(defadvice dired-advertised-find-file (around dired-subst-directory activate)
  "Replace current buffer if file is a directory."
  (interactive)
  (let ((orig (current-buffer))
        (filename (dired-get-filename)))
    ad-do-it
    (when (and (file-directory-p filename)
               (not (eq (current-buffer) orig)))
      (kill-buffer orig))))


;; Inserts the user name
(defun insert-userid ()
  "Insert the my full name and address"
  (interactive)
        (insert user-full-name " <" user-mail-address ">"))


;; Inserts the date in the format
(defun insert-date ()
  "Insert date at point."
  (interactive)
  (insert (format-time-string "%d.%m.%Y %H:%M")))

;;;;;;;;;;;;;;;;;;;;; Printing                          ;;;;;;;;;;;;;;;;;;;;;;;

;; Print two pages on 1 sheet of paper
(setq ps-n-up-printing 2)

;; remove that ugly header
(setq ps-print-header nil)

;;;;;;;;;;;;;;;;;;;;; Lisp Customization                ;;;;;;;;;;;;;;;;;;;;;;;


(defun my-lisp()
  "start up CLISP interactive windows in bottom "
  (interactive)
  (Windows
   (setq inferior-lisp-program "D:/clisp/lisp.exe -M D:/clisp/lispinit.mem")
   )
  (Linux
   (setq
    inferior-lisp-program "/usr/bin/clisp" ;; lisp binary
    compilation-scroll-output t            ;; put point at the end of the output window
    compilation-ask-about-save nil         ;; save all modified buffers without asking
    compilation-read-command 'nil          ;; do not ask for the compile command
    ;;(setq compile-command "make -k"
    ))
  (split-window-vertically)
  (other-window 1)
  (shrink-window 6)
  (run-lisp "lisp")
  )

(add-hook 'lisp-mode-hook 'my-lisp)

;;;;;;;;;;;;;;;;;;;;; SGML Customization                ;;;;;;;;;;;;;;;;;;;;;;;
(defun my-sgml()
  "start up psgml-mode with *Compile-Log* in the bottom"
  ;;   (interactive)
  ;;   (split-window-vertically)
  ;;   (other-window 1)
  ;;   (switch-to-buffer "*sgml validation*")
  ;;   (shrink-window 6)
  ;;   (other-window -1)
  ;; SGML markup faces.
  ;;
   (make-face 'sgml-comment-face)
   (make-face 'sgml-doctype-face)
   (make-face 'sgml-end-tag-face)
   (make-face 'sgml-entity-face)
   (make-face 'sgml-ignored-face)
   (make-face 'sgml-ms-end-face)
   (make-face 'sgml-ms-start-face)
   (make-face 'sgml-pi-face)
   (make-face 'sgml-sgml-face)
   (make-face 'sgml-short-ref-face)
   (make-face 'sgml-start-tag-face)

   (set-face-foreground 'sgml-comment-face "firebrick")
   (set-face-italic-p   'sgml-comment-face t)
   (set-face-foreground 'sgml-doctype-face "white")
   (set-face-background 'sgml-doctype-face "dodger blue")
   (set-face-foreground 'sgml-end-tag-face "dodger blue")
   ;; (set-face-bold-p     'sgml-end-tag-face 'nil)
   (set-face-foreground 'sgml-entity-face "red2")
   (set-face-foreground 'sgml-ignored-face "maroon")
   (set-face-background 'sgml-ignored-face "gray90")
   (set-face-foreground 'sgml-ms-end-face "maroon")
   (set-face-foreground 'sgml-ms-start-face "maroon")
   (set-face-foreground 'sgml-pi-face "maroon")
   (set-face-foreground 'sgml-sgml-face "maroon")
   (set-face-foreground 'sgml-short-ref-face "goldenrod")
   (set-face-foreground 'sgml-start-tag-face "dodger blue")
   ;; (set-face-bold-p     'sgml-start-tag-face 'nil)

 (setq-default
  sgml-markup-faces
  '(
    (comment . sgml-comment-face)
    (doctype . sgml-doctype-face)
    (end-tag . sgml-end-tag-face)
    (entity . sgml-entity-face)
    (ignored . sgml-ignored-face)
    (ms-end . sgml-ms-end-face)
    (ms-start . sgml-ms-start-face)
    (pi . sgml-pi-face)
    (sgml . sgml-sgml-face)
    (short-ref . sgml-short-ref-face)
    (start-tag . sgml-start-tag-face)
		)))

(add-hook 'sgml-mode-hook 'my-sgml)

;;;;;;;;;;;;;;;;;;;;; C/C++ Customization               ;;;;;;;;;;;;;;;;;;;;;;;
(defun my-c-mode()
  "Customizations for C/C++ mode"
  (interactive)
  (setq compilation-scroll-output t            ;; put point at the end of the output window
        compilation-ask-about-save nil         ;; save all modified buffers without asking
        compilation-read-command nil))         ;; do not ask for the compile command

(add-hook 'c-mode-hook 'my-c-mode)
(add-hook 'c++-mode-hook 'my-c-mode)

;;;;;;;;;;;;;;;;;;;;; Handle Desktop Sessions           ;;;;;;;;;;;;;;;;;;;;;;;
(require 'desktop)
(setq
 desktop-globals-to-save
 (append
  '((read-command-history . 9)
    (file-name-history . 9)
    (compile-history . 9)
    (command-history . 9)
    (extended-command-history . 9)
    (shell-command-history . 9)
    (query-replace-history . 9)
    (regexp-history . 9)
    (grep-history . 9)
    (compile-command . 9)
    (minibuffer-history . 9))
  desktop-globals-to-save))

(desktop-load-default)
(desktop-read)

;; Avoid saving too much data
(add-hook
 'kill-emacs-hook
 '(lambda ()
    (desktop-truncate search-ring 9)
    (desktop-truncate regexp-search-ring 9)))

;;;;;;;;;;;;;;;;;;;;; Autoinsert                        ;;;;;;;;;;;;;;;;;;;;;;;
(auto-insert-mode 1)
(add-hook 'find-file-hooks 'auto-insert)

;; Header files
(define-auto-insert
  (cons "\\.\\([Hh]\\)$" "C/C++ Header File Template")
  '(nil
    "/*\n"
    "\n"
    " $Header: $\n"
    " $Log: $\n"
                "\n"
    " \n"
    "\n"
    "*/\n"
    (let* ((noext (substring buffer-file-name 0 (match-beginning 0)))
           (nopath (file-name-nondirectory noext))
           (indent (concat "__" (upcase nopath)
                            "_" (upcase (file-name-extension buffer-file-name)))))
      (concat "#ifndef " indent "\n"
              "#define " indent "\n\n\n"
              "#endif /* " indent " */"))
    (previous-line 7)
    (end-of-line)))

;;; C/C++ files
(define-auto-insert
  (cons "\\.\\([cC]\\)" "C/C++ Source File Template")
  '(nil
    "/*\n"
    "\n"
    " $Header: $\n"
    " $Log: $\n"
                "\n"
    " \n"
                "\n"
    "*/\n"
    (let* ((nopath (file-name-nondirectory buffer-file-name))
                (noext  (file-name-sans-extension nopath)))
      (concat  "#include \"" noext ".h\"\n\n"))
    (previous-line 5)
    (end-of-line)))

;;; AWK files
(define-auto-insert
  (cons "\\.\\(awk\\)" "AWK File Template")
  '(nil
    "#!/bin/bash\n"
                "#\n"
    "# $Header: $\n"
    "# $Log: $\n"
    "#\n"
    "# \n"
    "#\n"
                "BEGIN{}\n"
                "{\n"
                "\n"
                "}\n"
    (previous-line 6)
    (end-of-line)))

;;; HTML files
(define-auto-insert
  (cons "\\.\\(htm\\)" "HTML File Template")
  '(nil
    "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 3.2//EN\">\n"
    "<html>\n"
    "  <head>\n"
    "    <title>\n"
    "\n"
    "    </title>\n"
    "    <meta http-equiv=\"content-type\" content=\"text/html; charset=windows-1251\">\n"
    "    <meta name=\"generator\" content=\"GNUEmacs\">\n"
    "    <meta name=\"keywords\" content=\"TODO\">\n"
    "    <meta name=\"description\" content=\"TODO\">\n"
    "  </head>\n"
    "  <body>\n"
    "    \n"
    "    <p align=\"right\"><b>Best</b> <i>viewed</i> <a><u>with</u></a> Lynx</p>\n"
    "  </body>\n"
    "</html>\n"
    (previous-line 4)
    (end-of-line)))

;;;;;;;;;;;;;;;;;;;;; Linux  Setup                      ;;;;;;;;;;;;;;;;;;;;;;;

(GNULinux
 (define-key global-map [(delete)]    "\C-d")


 (create-fontset-from-fontset-spec
  "-adobe-courier-medium-r-*-*-14-*-*-*-*-*-fontset-adobe,
 latin-iso8859-1:-adobe-courier-medium-r-*-*-14-*-*-*-*-*-*-1,
 latin-iso8859-2:-adobe-courier-medium-r-*-*-14-*-*-*-*-*-*-2,
 cyrillic-iso8859-5:-adobe-courier-medium-r-*-*-14-*-*-*-*-*-*-5")

 (create-fontset-from-fontset-spec
  "-adobe-courier-medium-o-*-*-14-*-*-*-*-*-fontset-adobe,
 latin-iso8859-1:-adobe-courier-medium-o-*-*-14-*-*-*-*-*-*-1,
 latin-iso8859-2:-adobe-courier-medium-o-*-*-14-*-*-*-*-*-*-2,
 cyrillic-iso8859-5:-adobe-courier-medium-o-*-*-14-*-*-*-*-*-*-5")

 (create-fontset-from-fontset-spec
  "-adobe-courier-bold-o-*-*-14-*-*-*-*-*-fontset-adobe,
 latin-iso8859-1:-adobe-courier-bold-o-*-*-14-*-*-*-*-*-*-1,
 latin-iso8859-2:-adobe-courier-bold-o-*-*-14-*-*-*-*-*-*-2,
 cyrillic-iso8859-5:-adobe-courier-bold-o-*-*-14-*-*-*-*-*-*-5")

 (create-fontset-from-fontset-spec
  "-adobe-courier-bold-r-*-*-14-*-*-*-*-*-fontset-adobe,
 latin-iso8859-1:-adobe-courier-bold-r-*-*-14-*-*-*-*-*-*-1,
 latin-iso8859-2:-adobe-courier-bold-r-*-*-14-*-*-*-*-*-*-2,
 cyrillic-iso8859-5:-adobe-courier-bold-r-*-*-14-*-*-*-*-*-*-5")

 (set-default-font "fontset-adobe")

 (setq default-frame-alist
       '(
          (top . 5) (left . 5)
         (width . 110) (height . 44)
         (cursor-color . "black")
         (cursor-type . box)
         (foreground-color . "black")
         (background-color . "white")
         )
       )
 );;GNULinux

;;;;;;;;;;;;;;;;;;;;; Windows  Setup                    ;;;;;;;;;;;;;;;;;;;;;;;

;; WinNT fontset for maximum i18n
(Windows
 (set-w32-system-coding-system 'cp1251)
 (setq w32-standard-fontset-spec
                         "-*-Courier New-normal-r-*-*-12-*-*-*-c-*-fontset-courier,
    ascii:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-1,
    latin-iso8859-1:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-1,
    latin-iso8859-2:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-2,
    latin-iso8859-3:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-3,
    latin-iso8859-4:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-4,
    latin-iso8859-9:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-9,

    cyrillic-iso8859-5:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-5,
    greek-iso8859-7:-*-Courier New-normal-r-*-*-12-*-*-*-c-*-iso8859-7,
    hebrew-iso8859-8:-*-Rod-normal-r-*-*-12-*-*-*-c-*-iso8859-8,

    ipa:-*-Lucida Sans Unicode-normal-r-*-*-12-*-*-*-c-*-muleipa*-*,

    thai-tis620:-*-Tahoma-normal-r-*-*-12-*-*-*-c-*-tis620-*,

    latin-jisx0201:-*-MS Gothic-normal-r-*-*-12-*-*-*-c-*-jisx0208-sjis,
    katakana-jisx0201:-*-MS Gothic-normal-r-*-*-12-*-*-*-c-*-jisx0208-sjis,
    japanese-jisx0208:-*-MS Gothic-normal-r-*-*-12-*-*-*-c-*-jisx0208-sjis,
    japanese-jisx0208-1978:-*-MS Gothic-normal-r-*-*-12-*-*-*-c-*-jisx0208-sjis,
    japanese-jisx0212:-*-MS Gothic-normal-r-*-*-12-*-*-*-c-*-jisx0212-sjis,
    korean-ksc5601:-*-Gulim-normal-r-*-*-12-*-*-*-c-*-ksc5601-*,
    chinese-gb2312:-*-MS Song-normal-r-*-*-12-*-*-*-c-*-gb2312-*,
    chinese-big5-1:-*-MingLiU-normal-r-*-*-12-*-*-*-c-*-big5-*,
    chinese-big5-2:-*-MingLiU-normal-r-*-*-12-*-*-*-c-*-big5-*")

 (setq w32-enable-italics t)
 (create-fontset-from-fontset-spec w32-standard-fontset-spec t)

;; Use a unix-style font dialog
 (setq w32-use-w32-font-dialog nil)
 (setq w32-fixed-font-alist '("Select Fontset"))

 ;; setting the default fontset
 ;; (set-frame-font "fontset-courier")

 ;; Set up BDF fonts:
 (setq bdf-directory-list
       '("d:/intlfonts/Asian"       "d:/intlfonts/Chinese"
         "d:/intlfonts/Chinese.X"   "d:/intlfonts/Ethiopic"
         "d:/intlfonts/European"    "d:/intlfonts/Japanese"
         "d:/intlfonts/Japanese.X"  "d:/intlfonts/Korean.X"
         "d:/intlfonts/Misc/" "d:/intlfonts/Japanese.BIG"))
 (setq w32-bdf-filename-alist (w32-find-bdf-fonts bdf-directory-list))


 ;; Setting the network printer
 (setq ps-printer-name "//server/printer")

 ;; BDF fonts for printing
 (load-library "ps-mule")       ;; needed for setting some variables below

 (setq ps-multibyte-buffer
       'bdf-font
       ps-mule-font-info-database ps-mule-font-info-database-bdf
       bdf-directory-list
       '(
         "d:/intlfonts/Asian"
         "d:/intlfonts/Chinese"
         "d:/intlfonts/Chinese.X"
         "d:/intlfonts/Ethiopic"
         "d:/intlfonts/European"
         "d:/intlfonts/Japanese"
         "d:/intlfonts/Japanese.X"
         "d:/intlfonts/Korean.X"
         "d:/intlfonts/Misc"
         "d:/intlfonts/Japanese.BIG")
       )

 ;; bdf-only fontset
 (create-fontset-from-fontset-spec
  "-*-fixed-medium-r-normal-*-16-*-*-*-c-*-fontset-bdf,
 japanese-jisx0208:-*-*-medium-r-normal-*-16-*-*-*-c-*-jisx0208.1983-*,
 katakana-jisx0201:-*-*-medium-r-normal-*-16-*-*-*-c-*-jisx0201*-*,
 latin-jisx0201:-*-*-medium-r-normal-*-16-*-*-*-c-*-jisx0201*-*,
 japanese-jisx0208-1978:-*-*-medium-r-normal-*-16-*-*-*-c-*-jisx0208.1978-*,
 thai-tis620:-misc-fixed-medium-r-normal--16-160-72-72-m-80-tis620.2529-1,
 lao:-misc-fixed-medium-r-normal--16-160-72-72-m-80-MuleLao-1,
 tibetan-1-column:-TibMdXA-fixed-medium-r-normal--16-160-72-72-m-80-MuleTibetan-1,
 ethiopic:-Admas-Ethiomx16f-Medium-R-Normal--16-150-100-100-M-160-Ethiopic-Unicode,
 tibetan:-TibMdXA-fixed-medium-r-normal--16-160-72-72-m-160-MuleTibetan-0")

 ;; Need to add some fonts to font-encoding-alist since the bdf fonts
 ;; are type 0 not the default type 1.
 (setq font-encoding-alist
       (append '(("MuleTibetan-0" (tibetan . 0))
                 ("GB2312"        (chinese-gb2312 . 0))
                 ("JISX0208"      (japanese-jisx0208 . 0))
                 ("JISX0212"      (japanese-jisx0212 . 0))
                 ("VISCII"        (vietnamese-viscii-lower . 0))
                 ("KSC5601"       (korean-ksc5601 . 0))
                 ("MuleArabic-0"  (arabic-digit . 0))
                 ("MuleArabic-1"  (arabic-1-column . 0))
                 ("MuleArabic-2"  (arabic-2-column . 0)))
               font-encoding-alist))

 (setq default-frame-alist
       '(
         (top . 2) (left . 5)
         (width . 120) (height . 43)
         (cursor-color . "black")
         (cursor-type . box)
         (foreground-color . "black")
         (background-color . "white")
         (font . "-*-Courier New-normal-r-*-*-12-*-*-*-c-*-fontset-courier")
         )
       )

 ;; Setting bash as the default emacs shell
 (defun my-shell-setup ()
   "For bash (cygwin 18) under Emacs 20"
   (setq comint-scroll-show-maximum-output 'this)
   (setq comint-completion-addsuffix t)
   ;; (setq comint-process-echoes t) ;; reported that this is no longer needed
   (setq comint-eol-on-send t)
   (setq w32-quote-process-args ?\")
   (make-variable-buffer-local 'comint-completion-addsuffix))

 (setq shell-mode-hook 'my-shell-setup)
 (setq binary-process-input t)

 (setq process-coding-system-alist
       (cons
        '("bash" . cp1251)
        process-coding-system-alist))

 ) ;; Match Windows


;;;;;;;;;;;;;;;;;;;;; Fontsets Setup                    ;;;;;;;;;;;;;;;;;;;;;;;

(custom-set-faces
 '(modeline ((t (:inverse-video nil :foreground "black" :background "skyblue"))))
 '(font-lock-comment-face ((((class color)) (:foreground "firebrick" :italic t))))
 '(font-lock-keyword-face ((((class color)) (:foreground "dodger blue" :bold t) )))
 '(font-lock-function-name-face ((((class color)) (:foreground "DarkSlateBlue" :bold t) )))
 '(info-xref ((t (:bold t :foreground "DarkBlue"))))
 '(info-node ((t (:bold t :italic t :foreground "firebrick"))))
 '(message-headers ((t (:foreground "forestgreen" :size "15" :bold t))))
 '(message-header-contents ((t (:foreground "rosybrown" :italic t))))
 '(message-highlighted-header-contents ((t (:foreground "red" :bold t :italic t))))
 )


;;; Local Variables: ***
;;; mode:emacs-lisp ***
;;; mode:outline-minor ***
;;; outline-regexp: ";;;;;;;;;;.*;;;;;;;;;;" ***
;;; End: ***

